==> content_snapshot-3.0.0.tar.gz: content_snapshot/src/Logger/Logger.php <==
<?php

/**
 * @file
 */

namespace Drupal\content_snapshot\Logger;

/**
 * Class Logger.
 */
class Logger implements LoggerInterface {


  /**
   * @var \Psr\Log\LoggerInterface
   */
  private $logger;

  /**
   * @param \Psr\Log\LoggerInterface $logger
   */
  public function setLogger(\Psr\Log\LoggerInterface $logger): void {
    $this->logger = $logger;
  }

  public function emergency(string|\Stringable $message, array $context = []): void {
    $this->logger->emergency($message, $context);
  }

  public function alert(string|\Stringable $message, array $context = []): void {
    $this->logger->alert($message, $context);
  }

  public function critical(string|\Stringable $message, array $context = []): void {
    $this->logger->critical($message, $context);
  }

  public function error(string|\Stringable $message, array $context = []): void {
    $this->logger->error($message, $context);
  }

  public function warning(string|\Stringable $message, array $context = []): void {
    $this->logger->warning($message, $context);
  }

  public function notice(string|\Stringable $message, array $context = []): void {
    $this->logger->notice($message, $context);
  }

  public function info(string|\Stringable $message, array $context = []): void {
    $this->logger->info($message, $context);
  }

  public function debug(string|\Stringable $message, array $context = []): void {
    $this->logger->debug($message, $context);
  }

  public function log($level, string|\Stringable $message, array $context = []): void {
    $this->logger->log($level, $message, $context);
  }

}

==> content_snapshot-3.0.3.tar.gz: content_snapshot/src/Logger/Logger.php <==
<?php

namespace Drupal\content_snapshot\Logger;

use Psr\Log\LoggerInterface as BaseLogger;

/**
 * Default logger.
 */
class Logger implements LoggerInterface {


  /**
   * The Logger Interface.
   *
   * @var \Psr\Log\LoggerInterface
   */
  private $logger;

  /**
   * Implements setLogger().
   *
   * @param \Psr\Log\LoggerInterface $logger
   *   Logger Interface.
   */
  public function setLogger(BaseLogger $logger): void {
    $this->logger = $logger;
  }

  /**
   * Implements emergency().
   */
  public function emergency(string|\Stringable $message, array $context = []): void {
    $this->logger->emergency($message, $context);
  }

  /**
   * Implements alert().
   */
  public function alert(string|\Stringable $message, array $context = []): void {
    $this->logger->alert($message, $context);
  }

  /**
   * Implements critical().
   */
  public function critical(string|\Stringable $message, array $context = []): void {
    $this->logger->critical($message, $context);
  }

  /**
   * Implements error().
   */
  public function error(string|\Stringable $message, array $context = []): void {
    $this->logger->error($message, $context);
  }

  /**
   * Implements warning().
   */
  public function warning(string|\Stringable $message, array $context = []): void {
    $this->logger->warning($message, $context);
  }

  /**
   * Implements notice().
   */
  public function notice(string|\Stringable $message, array $context = []): void {
    $this->logger->notice($message, $context);
  }

  /**
   * Implements info().
   */
  public function info(string|\Stringable $message, array $context = []): void {
    $this->logger->info($message, $context);
  }

  /**
   * Implements debug().
   */
  public function debug(string|\Stringable $message, array $context = []): void {
    $this->logger->debug($message, $context);
  }

  /**
   * Implements log().
   */
  public function log($level, string|\Stringable $message, array $context = []): void {
    $this->logger->log($level, $message, $context);
  }

}
